@@ -32,7 +32,7 @@
   #define XDMF_BYTE_ORDER_LITTLE
 #endif
 
-#define XDMF_SYSTEM Linux-5.17.1-1-ARCH
+#define XDMF_SYSTEM Linux-6.17.7-3-armv7-ARCH
 
 #define XDMF_VOID_VALID
 #ifndef XDMF_VOID_VALID
